// java wrapper for vtkSortDataArray object
//

package vtk;
import vtk.*;

public class vtkSortDataArray extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Sort_2(vtkIdList id0);
  public void Sort(vtkIdList id0)
    { Sort_2(id0); }

  private native void Sort_3(vtkAbstractArray id0);
  public void Sort(vtkAbstractArray id0)
    { Sort_3(id0); }

  private native void Sort_4(vtkIdList id0,int id1);
  public void Sort(vtkIdList id0,int id1)
    { Sort_4(id0,id1); }

  private native void Sort_5(vtkAbstractArray id0,int id1);
  public void Sort(vtkAbstractArray id0,int id1)
    { Sort_5(id0,id1); }

  private native void Sort_6(vtkAbstractArray id0,vtkAbstractArray id1);
  public void Sort(vtkAbstractArray id0,vtkAbstractArray id1)
    { Sort_6(id0,id1); }

  private native void Sort_7(vtkAbstractArray id0,vtkIdList id1);
  public void Sort(vtkAbstractArray id0,vtkIdList id1)
    { Sort_7(id0,id1); }

  private native void Sort_8(vtkAbstractArray id0,vtkAbstractArray id1,int id2);
  public void Sort(vtkAbstractArray id0,vtkAbstractArray id1,int id2)
    { Sort_8(id0,id1,id2); }

  private native void Sort_9(vtkAbstractArray id0,vtkIdList id1,int id2);
  public void Sort(vtkAbstractArray id0,vtkIdList id1,int id2)
    { Sort_9(id0,id1,id2); }

  private native void SortArrayByComponent_10(vtkAbstractArray id0,int id1);
  public void SortArrayByComponent(vtkAbstractArray id0,int id1)
    { SortArrayByComponent_10(id0,id1); }

  private native void SortArrayByComponent_11(vtkAbstractArray id0,int id1,int id2);
  public void SortArrayByComponent(vtkAbstractArray id0,int id1,int id2)
    { SortArrayByComponent_11(id0,id1,id2); }

  public vtkSortDataArray() { super(); }

  public vtkSortDataArray(long id) { super(id); }
  public native long   VTKInit();

}
